@@ -30,8 +30,6 @@
 #include <KContacts/Addressee>
 #include <KAssistantDialog>
 
-#include <QStringList>
-
 namespace KAddressBookImportExport {
 class KAddressBookContactSelectionWidget;
 }
@@ -119,17 +117,17 @@ protected:
         {
         }
 
-        PrintStyleFactory *printstyleFactory;
-        PrintStyle *printStyle;
+        PrintStyleFactory *printstyleFactory = nullptr;
+        PrintStyle *printStyle = nullptr;
     };
 
     QList<PrintStyleDefinition *> mPrintStyleDefinition;
-    QPrinter *mPrinter;
-    PrintStyle *mStyle;
-    PrintProgress *mProgress;
+    QPrinter *mPrinter = nullptr;
+    PrintStyle *mStyle = nullptr;
+    PrintProgress *mProgress = nullptr;
 
-    StylePage *mStylePage;
-    KAddressBookImportExport::KAddressBookContactSelectionWidget *mSelectionPage;
+    StylePage *mStylePage = nullptr;
+    KAddressBookImportExport::KAddressBookContactSelectionWidget *mSelectionPage = nullptr;
 
     /**
      * Overloaded accept slot. This is used to do the actual
